@@ -5,7 +5,7 @@ use warnings;
 package Dist::Zilla::Plugin::BumpVersionAfterRelease;
 # ABSTRACT: Bump module versions after distribution release
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 use Moose;
 with(
@@ -102,7 +102,7 @@ sub rewrite_version {
     my $iolayer = sprintf( ":raw:encoding(%s)", $file->encoding );
 
     # read source file
-    my $content = Path::Tiny::path( $file->name )->slurp( { binmode => $iolayer } );
+    my $content = Path::Tiny::path( $file->_original_name )->slurp( { binmode => $iolayer } );
 
     my $comment = $self->zilla->is_trial ? ' # TRIAL' : '';
     my $code = "our \$VERSION = '$version';$comment";
@@ -159,7 +159,7 @@ Dist::Zilla::Plugin::BumpVersionAfterRelease - Bump module versions after distri
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -300,6 +300,10 @@ L<Dist::Zilla::Plugin::SurgicalPkgVersion>
 
 L<Dist::Zilla::Plugin::PkgVersionIfModuleWithPod>
 
+=item *
+
+L<Dist::Zilla::Plugin::RewriteVersion::Transitional>
+
 =back
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
